@@ -182,6 +182,17 @@ model.binomial <- function(network)
     } else if(type == "fixed"){
       code <- paste0(code, rank.rjags(rank.preference, ntreat))
     }
+    
+    if(!is.null(mean.A) & !is.null(prec.A)){
+      code <- paste0(code,
+                     "\n\tA ~ dnorm(mean.A, prec.A)",
+                     "\n\tfor(k in 1:", ntreat, ") { logit(T[k]) <- A + d[k] }",
+                     "\n\tfor(k in 1:", ntreat, ") {",
+                     "\n\t\tRD[k] <- T[k] - T[1]",
+                     "\n\t\tRR[k] <- T[k]/T[1]",
+                     "\n\t}")
+    }
+    
     return(code)
   })
 }
